# 990 XML Metadata

This repository contains metadata that IRSx uses to parse IRS 990 XML schemas. These files have been separated into their own repository so that [IRSx](https://github.com/jsfenfen/990-xml-reader/) doesn't need a new version every time the metadata files are updated, and so that they can be used by parsers written in other languages.

For more on submodules on github, see [here](https://blog.github.com/2016-02-01-working-with-submodules/).